from django.urls import path

from environment import views

urlpatterns = [
    path("", views.research_environments, name="research_environments"),
    path(
        "billing/manage/<billing_account_id>",
        views.manage_billing_account,
        name="manage_billing_account",
    ),
    path(
        "billing/confirm",
        views.confirm_billing_account_sharing,
        name="confirm_billing_account_sharing",
    ),
    path(
        "environments-card/",
        views.research_environments_partial,
        name="research_environments_partial",
    ),
    path(
        "identity-provisioning/",
        views.identity_provisioning,
        name="identity_provisioning",
    ),
    path(
        "environment/stop",
        views.stop_running_environment,
        name="stop_running_environment",
    ),
    path(
        "environment/start",
        views.start_stopped_environment,
        name="start_stopped_environment",
    ),
    path(
        "environment/update",
        views.change_environment_machine_type,
        name="change_environment_machine_type",
    ),
    path("environment/delete", views.delete_environment, name="delete_environment"),
    path(
        "environment/create/<workspace_id>",
        views.create_research_environment,
        name="create_research_environment",
    ),
    path(
        "execution/check-status",
        views.check_execution_status,
        name="check_execution_status",
    ),
    path("workspace/create", views.create_workspace, name="create_workspace"),
    path("workspace/delete", views.delete_workspace, name="delete_workspace"),
    path(
        "workspace/quotas/<workspace_region>/<workspace_project_id>",
        views.get_quotas,
        name="get_quotas",
    ),
    path(
        "sharing/workspace/create",
        views.create_shared_workspace,
        name="create_shared_workspace",
    ),
    path(
        "sharing/workspace/delete",
        views.delete_shared_workspace,
        name="delete_shared_workspace",
    ),
    path(
        "sharing/bucket/create/<workspace_id>",
        views.create_shared_bucket,
        name="create_shared_bucket",
    ),
    path(
        "sharing/bucket/delete", views.delete_shared_bucket, name="delete_shared_bucket"
    ),
    path(
        "sharing/manage/<shared_workspace_name>/<shared_bucket_name>",
        views.manage_shared_bucket,
        name="manage_shared_bucket",
    ),
    path(
        "sharing/manage/<shared_workspace_name>/<shared_bucket_name>/files",
        views.manage_shared_bucket_files,
        name="manage_shared_bucket_files",
    ),
    path(
        "sharing/confirm",
        views.confirm_bucket_sharing,
        name="confirm_bucket_sharing",
    ),
    path(
        "sharing/generate_signed_url/<bucket_name>",
        views.generate_signed_url,
        name="generate_bucket_signed_url",
    ),
    path(
        "sharing/<bucket_name>",
        views.get_shared_bucket_content,
        name="get_shared_bucket_content",
    ),
    path(
        "sharing/<bucket_name>/content/create",
        views.create_shared_bucket_directory,
        name="create_shared_bucket_directory",
    ),
    path(
        "sharing/<bucket_name>/content/delete",
        views.delete_shared_bucket_content,
        name="delete_shared_bucket_content",
    ),
    path("console/group/create", views.create_cloud_group, name="create_cloud_group"),
    path("console/group/delete", views.delete_cloud_group, name="delete_cloud_group"),
    path(
        "console/group/add/<user_id>",
        views.add_user_to_cloud_group,
        name="add_user_to_cloud_group",
    ),
    path(
        "console/group/remove/<user_id>",
        views.remove_user_from_cloud_group,
        name="remove_user_from_cloud_group",
    ),
    path("console/group", views.cloud_groups, name="cloud_groups"),
    path(
        "console/group/management",
        views.cloud_groups_management,
        name="cloud_groups_management",
    ),
    path(
        "console/group/management-table",
        views.cloud_groups_management_partial,
        name="cloud_groups_management_partial",
    ),
    path(
        "console/group/<cloud_group_id>/roles/add",
        views.add_roles_to_cloud_group,
        name="add_roles_to_cloud_group",
    ),
    path(
        "console/group/<cloud_group_id>/roles/remove",
        views.remove_roles_from_cloud_group,
        name="remove_roles_from_cloud_group",
    ),
    path(
        "console/monitoring/datasets",
        views.get_datasets_monitoring_data,
        name="get_datasets_monitoring_data",
    ),
]
